package models

type NewWarehousing struct {
	ID                int64        `gorm:"column:id" json:"id"`
	WarehousingOrder  string       `gorm:"column:warehousing_order" json:"warehousing_order"`
	OperationTime     int64        `gorm:"column:operation_time" json:"operation_time"`
	OrgId             int64        `gorm:"column:org_id" json:"org_id"`
	Creater           int64        `gorm:"column:creater" json:"creater"`
	Ctime             int64        `gorm:"column:ctime" json:"ctime"`
	Modifier          int64        `gorm:"column:modifier" json:"modifier"`
	Mtime             int64        `gorm:"column:mtime" json:"mtime"`
	Status            int64        `gorm:"column:status" json:"status"`
	WarehousingTime   int64        `gorm:"column:warehousing_time" json:"warehousing_time"`
	Dealer            int64        `gorm:"column:dealer" json:"dealer"`
	Manufacturer      int64        `gorm:"column:manufacturer" json:"manufacturer"`
	Manufacturers     Manufacturer `gorm:"ForeignKey:ID;AssociationForeignKey:Manufacturer" json:"Manufacturer"`
	Dealers           Dealers      `gorm:"ForeignKey:ID;AssociationForeignKey:Dealer" json:"Dealer"`
	Type              int64        `gorm:"column:type" json:"type"`
	SupplyWarehouseId int64        `gorm:"column:supply_warehouse_id" json:"supply_warehouse_id" form:"supply_warehouse_id"`
	StorehouseId      int64        `gorm:"column:storehouse_id" json:"storehouse_id" form:"storehouse_id"`
	IsSys             int64        `gorm:"column:is_sys" json:"is_sys" form:"is_sys"`
	SecondWarehouseId int64        `gorm:"column:second_warehouse_id" json:"second_warehouse_id" form:"second_warehouse_id"`
	IsCheck           int64        `gorm:"column:is_check" json:"is_check" form:"is_check"`
}

func (NewWarehousing) TableName() string {
	return "xt_warehouse"
}

type NewWarehousingInfo struct {
	ID                    int64        `gorm:"column:id" json:"id"`
	WarehousingId         int64        `gorm:"column:warehousing_id" json:"warehousing_id"`
	GoodId                int64        `gorm:"column:good_id" json:"good_id"`
	GoodTypeId            int64        `gorm:"column:good_type_id" json:"good_type_id"`
	Number                string       `gorm:"column:number" json:"number"`
	ProductDate           int64        `gorm:"column:product_date" json:"product_date"`
	ExpiryDate            int64        `gorm:"column:expiry_date" json:"expiry_date"`
	WarehousingCount      int64        `gorm:"column:warehousing_count" json:"warehousing_count"`
	WarehousingUnit       string       `gorm:"column:warehousing_unit" json:"warehousing_unit"`
	Price                 float64      `gorm:"column:price" json:"price"`
	TotalPrice            float64      `gorm:"column:total_price" json:"total_price"`
	Dealer                int64        `gorm:"column:dealer" json:"dealer"`
	Manufacturer          int64        `gorm:"column:manufacturer" json:"manufacturer"`
	Remark                string       `gorm:"column:remark" json:"remark"`
	Ctime                 int64        `gorm:"column:ctime" json:"ctime"`
	Mtime                 int64        `gorm:"column:mtime" json:"mtime"`
	Status                int64        `gorm:"column:status" json:"status"`
	OrgId                 int64        `gorm:"column:org_id" json:"org_id"`
	IsReturn              int64        `gorm:"column:is_return" json:"is_return"`
	StockCount            int64        `gorm:"column:stock_count" json:"stock_count" form:"stock_count"`
	WarehousingOrder      string       `gorm:"column:warehousing_order" json:"warehousing_order"`
	Type                  int64        `gorm:"column:type" json:"type"`
	GoodName              string       `json:"good_name"`
	PackingUnit           string       `json:"packing_unit"`
	TotalCount            int64        `json:"total_count"`
	SpecificationName     string       `json:"specification_name"`
	LicenseNumber         string       `gorm:"column:license_number" json:"license_number" form:"license_number"`
	StorehouseId          int64        `gorm:"column:storehouse_id" json:"storehouse_id" form:"storehouse_id"`
	SecondWarehouseInfoId int64        `gorm:"column:second_warehouse_info_id" json:"second_warehouse_info_id" form:"second_warehouse_info_id"`
	GoodInfo              GoodInfo     `gorm:"ForeignKey:ID;AssociationForeignKey:GoodId" json:"infos"`
	Manufacturers         Manufacturer `gorm:"ForeignKey:ID;AssociationForeignKey:Manufacturer" json:"Manufacturer"`
	Dealers               Dealers      `gorm:"ForeignKey:ID;AssociationForeignKey:Dealer" json:"Dealer"`
}

func (NewWarehousingInfo) TableName() string {
	return "xt_warehouse_info"
}

type NewWarehouseOut struct {
	ID                      int64        `gorm:"column:id" json:"id"`
	WarehouseOutOrderNumber string       `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number"`
	OperationTime           int64        `gorm:"column:operation_time" json:"operation_time"`
	Creater                 int64        `gorm:"column:creater" json:"creater"`
	OrgId                   int64        `gorm:"column:org_id" json:"org_id"`
	Modifier                int64        `gorm:"column:modifier" json:"modifier"`
	Remark                  string       `gorm:"column:remark" json:"remark"`
	Ctime                   int64        `gorm:"column:ctime" json:"ctime"`
	Mtime                   int64        `gorm:"column:mtime" json:"mtime"`
	Status                  int64        `gorm:"column:status" json:"status"`
	WarehouseOutTime        int64        `gorm:"column:warehouse_out_time" json:"warehouse_out_time"`
	Dealer                  int64        `gorm:"column:dealer" json:"dealer"`
	Manufacturer            int64        `gorm:"column:manufacturer" json:"manufacturer"`
	Manufacturers           Manufacturer `gorm:"ForeignKey:ID;AssociationForeignKey:Manufacturer" json:"Manufacturer"`
	Dealers                 Dealers      `gorm:"ForeignKey:ID;AssociationForeignKey:Dealer" json:"Dealer"`
	Type                    int64        `gorm:"column:type" json:"type"`
	IsSys                   int64        `gorm:"column:is_sys" json:"is_sys"`
	SupplyCancelOutId       int64        `gorm:"column:supply_cancel_out_id" json:"supply_cancel_out_id" form:"supply_cancel_out_id"`
	SupplyWarehouseId       int64        `gorm:"column:supply_warehouse_id" json:"supply_warehouse_id" form:"supply_warehouse_id"`
	StorehouseId            int64        `gorm:"column:storehouse_id" json:"storehouse_id" form:"storehouse_id"`
	SecondWarehouseId       int64        `gorm:"column:second_warehouse_id" json:"second_warehouse_id" form:"second_warehouse_id"`
	IsCheck                 int64        `gorm:"column:is_check" json:"is_check" form:"is_check"`
}

func (NewWarehouseOut) TableName() string {
	return "xt_warehouse_out"
}

type NewWarehouseOutInfo struct {
	ID                      int64           `gorm:"column:id" json:"id"`
	WarehouseOutId          int64           `gorm:"column:warehouse_out_id" json:"warehouse_out_id"`
	WarehouseInfotId        int64           `gorm:"column:warehouse_info_id" json:"warehouse_info_id"`
	GoodId                  int64           `gorm:"column:good_id" json:"good_id"`
	GoodTypeId              int64           `gorm:"column:good_type_id" json:"good_type_id"`
	WarehousingOutTarget    int64           `gorm:"column:warehousing_out_target" json:"warehousing_out_target"`
	Count                   int64           `gorm:"column:count" json:"count"`
	Price                   float64         `gorm:"column:price" json:"price"`
	TotalPrice              float64         `gorm:"column:total_price" json:"total_price"`
	ProductDate             int64           `gorm:"column:product_date" json:"product_date"`
	ExpiryDate              int64           `gorm:"column:expiry_date" json:"expiry_date"`
	Mtime                   int64           `gorm:"column:mtime" json:"mtime"`
	Ctime                   int64           `gorm:"column:ctime" json:"ctime"`
	Status                  int64           `gorm:"column:status" json:"status"`
	OrgId                   int64           `gorm:"column:org_id" json:"org_id"`
	Remark                  string          `gorm:"column:remark" json:"remark"`
	IsCancel                int64           `gorm:"column:is_cancel" json:"is_cancel"`
	WarehouseOutOrderNumber string          `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number"`
	GoodInfo                GoodInfo        `gorm:"ForeignKey:ID;AssociationForeignKey:GoodId" json:"info"`
	Type                    int64           `gorm:"column:type" json:"type"`
	Dealer                  int64           `gorm:"column:dealer" json:"dealer"`
	Manufacturer            int64           `gorm:"column:manufacturer" json:"manufacturer"`
	IsSys                   int64           `gorm:"column:is_sys" json:"is_sys"`
	SysRecordTime           int64           `gorm:"column:sys_record_time" json:"sys_record_time"`
	PatientId               int64           `gorm:"column:patient_id" json:"patient_id"`
	Number                  string          `gorm:"column:number" json:"number" form:"number"`
	LicenseNumber           string          `gorm:"column:license_number" json:"license_number" form:"license_number"`
	ConsumableType          int64           `gorm:"column:consumable_type" json:"consumable_type" form:"consumable_type"`
	ProjectId               int64           `gorm:"column:project_id" json:"project_id" form:"project_id"`
	SupplyCancelOutId       int64           `gorm:"column:supply_cancel_out_id" json:"supply_cancel_out_id" form:"supply_cancel_out_id"`
	SupplyWarehouseId       int64           `gorm:"column:supply_warehouse_id" json:"supply_warehouse_id" form:"supply_warehouse_id"`
	IsSource                int64           `gorm:"column:is_source" json:"is_source" form:"is_source"`
	StorehouseId            int64           `gorm:"column:storehouse_id" json:"storehouse_id" form:"storehouse_id"`
	SecondWarehouseInfoId   int64           `gorm:"column:second_warehouse_info_id" json:"second_warehouse_info_id" form:"second_warehouse_info_id"`
	AdminUserId             int64           `gorm:"column:admin_user_id" json:"admin_user_id" form:"admin_user_id"`
	BuyPrice                float64         `gorm:"column:buy_price" json:"buy_price" form:"buy_price"`
	StockCount              string          `gorm:"column:stock_count" json:"stock_count" form:"stock_count"`
	IsCheck                 int64           `gorm:"column:is_check" json:"is_check" form:"is_check"`
	RegisterNumber          string          `gorm:"column:register_number" json:"register_number" form:"register_number"`
	WarehousingInfo         WarehousingInfo `gorm:"ForeignKey:ID;AssociationForeignKey:WarehouseInfotId" `
	VmStockFlow             VmStockFlow     `gorm:"ForeignKey:ID;AssociationForeignKey:WarehouseOutDetailId" json:"stock_flow"`
	OverCount               int64           `gorm:"column:over_count" json:"over_count" form:"over_count"`
	Manufacturers           Manufacturer    `gorm:"ForeignKey:ID;AssociationForeignKey:Manufacturer" json:"Manufacturer"`
	Dealers                 Dealers         `gorm:"ForeignKey:ID;AssociationForeignKey:Dealer" json:"Dealer"`
}

func (NewWarehouseOutInfo) TableName() string {
	return "xt_warehouse_out_info"
}

type NewCancelStock struct {
	ID           int64  `gorm:"column:id" json:"id"`
	OrderNumber  string `gorm:"column:order_number" json:"order_number"`
	OperaTime    int64  `gorm:"column:opera_time" json:"opera_time"`
	Total        int64  `gorm:"column:total" json:"total"`
	Creater      int64  `gorm:"column:creater" json:"creater"`
	Ctime        int64  `gorm:"column:ctime" json:"ctime"`
	Mtime        int64  `gorm:"column:mtime" json:"mtime"`
	Status       int64  `gorm:"column:status" json:"status"`
	OrgId        int64  `gorm:"column:org_id" json:"org_id"`
	ReturnTime   int64  `gorm:"column:return_time" json:"return_time"`
	Dealer       int64  `gorm:"column:dealer" json:"dealer"`
	Manufacturer int64  `gorm:"column:manufacturer" json:"manufacturer"`
	Type         int64  `gorm:"column:type" json:"type"`
	StorehouseId int64  `gorm:"column:storehouse_id" json:"storehouse_id" form:"storehouse_id"`
	IsCheck      int64  `gorm:"column:is_check" json:"is_check" form:"is_check"`
}

func (NewCancelStock) TableName() string {
	return "xt_cancel_stock"
}

type NewCancelStockInfo struct {
	ID              int64        `gorm:"column:id" json:"id"`
	GoodId          int64        `gorm:"column:good_id" json:"good_id"`
	CancelStockId   int64        `gorm:"column:cancel_stock_id" json:"cancel_stock_id"`
	GoodTypeId      int64        `gorm:"column:good_type_id" json:"good_type_id"`
	Count           int64        `gorm:"column:count" json:"count"`
	Price           float64      `gorm:"column:price" json:"price"`
	Total           float64      `gorm:"column:total" json:"total"`
	ProductDate     int64        `gorm:"column:product_date" json:"product_date"`
	ExpiryDate      int64        `gorm:"column:expiry_date" json:"expiry_date"`
	Ctime           int64        `gorm:"column:ctime" json:"ctime"`
	Mtime           int64        `gorm:"column:mtime" json:"mtime"`
	Status          int64        `gorm:"column:status" json:"status"`
	OrgId           int64        `gorm:"column:org_id" json:"org_id"`
	OrderNumber     string       `gorm:"column:order_number" json:"order_number"`
	Type            int64        `gorm:"column:type" json:"type"`
	Dealer          string       `gorm:"column:dealer" json:"dealer"`
	Manufacturer    string       `gorm:"column:manufacturer" json:"manufacturer"`
	Number          string       `gorm:"column:number" json:"number" form:"number"`
	RegisterAccount string       `gorm:"column:register_account" json:"register_account" form:"register_account"`
	Remark          string       `gorm:"column:remark" json:"remark" form:"remark"`
	WarehouseInfoId int64        `gorm:"column:warehouse_info_id" json:"warehouse_info_id" form:"warehouse_info_id"`
	PatientId       int64        `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	RecordDate      int64        `gorm:"column:record_date" json:"record_date" form:"record_date"`
	StorehouseId    int64        `gorm:"column:storehouse_id" json:"storehouse_id" form:"storehouse_id"`
	IsCheck         int64        `gorm:"column:is_check" json:"is_check" form:"is_check"`
	GoodInfo        GoodInfo     `gorm:"ForeignKey:ID;AssociationForeignKey:GoodId" json:"info"`
	Manufacturers   Manufacturer `gorm:"ForeignKey:ID;AssociationForeignKey:Manufacturer" json:"Manufacturer"`
	Dealers         Dealers      `gorm:"ForeignKey:ID;AssociationForeignKey:Dealer" json:"Dealer"`
}

func (NewCancelStockInfo) TableName() string {
	return "xt_cancel_stock_info"
}

type NewDrugWarehouse struct {
	ID               int64  `gorm:"column:id" json:"id" form:"id"`
	WarehousingOrder string `gorm:"column:warehousing_order" json:"warehousing_order" form:"warehousing_order"`
	OperationTime    int64  `gorm:"column:operation_time" json:"operation_time" form:"operation_time"`
	OrgId            int64  `gorm:"column:org_id" json:"org_id" form:"org_id"`
	Creater          int64  `gorm:"column:creater" json:"creater" form:"creater"`
	Ctime            int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Modifier         int64  `gorm:"column:modifier" json:"modifier" form:"modifier"`
	Mtime            int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status           int64  `gorm:"column:status" json:"status" form:"status"`
	WarehousingTime  int64  `gorm:"column:warehousing_time" json:"warehousing_time" form:"warehousing_time"`
	Dealer           int64  `gorm:"column:dealer" json:"dealer" form:"dealer"`
	Manufacturer     int64  `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	Type             int64  `gorm:"column:type" json:"type" form:"type"`
}

func (NewDrugWarehouse) TableName() string {
	return "xt_drug_warehouse"
}

type NewDrugWarehouseInfo struct {
	ID               int64        `gorm:"column:id" json:"id" form:"id"`
	WarehousingId    int64        `gorm:"column:warehousing_id" json:"warehousing_id" form:"warehousing_id"`
	DrugId           int64        `gorm:"column:drug_id" json:"drug_id" form:"drug_id"`
	Number           string       `gorm:"column:number" json:"number" form:"number"`
	ProductDate      int64        `gorm:"column:product_date" json:"product_date" form:"product_date"`
	ExpiryDate       int64        `gorm:"column:expiry_date" json:"expiry_date" form:"expiry_date"`
	WarehousingCount int64        `gorm:"column:warehousing_count" json:"warehousing_count" form:"warehousing_count"`
	Price            float64      `gorm:"column:price" json:"price" form:"price"`
	TotalPrice       float64      `gorm:"column:total_price" json:"total_price" form:"total_price"`
	Dealer           int64        `gorm:"column:dealer" json:"dealer" form:"dealer"`
	Manufacturer     int64        `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	Remark           string       `gorm:"column:remark" json:"remark" form:"remark"`
	Ctime            int64        `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime            int64        `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status           int64        `gorm:"column:status" json:"status" form:"status"`
	OrgId            int64        `gorm:"column:org_id" json:"org_id" form:"org_id"`
	IsReturn         int64        `gorm:"column:is_return" json:"is_return" form:"is_return"`
	WarehousingOrder string       `gorm:"column:warehousing_order" json:"warehousing_order" form:"warehousing_order"`
	Type             int64        `gorm:"column:type" json:"type" form:"type"`
	RetailPrice      float64      `gorm:"column:retail_price" json:"retail_price" form:"retail_price"`
	RetailTotalPrice float64      `gorm:"column:retail_total_price" json:"retail_total_price" form:"retail_total_price"`
	BaseDrugLib      BaseDrugLib  `gorm:"ForeignKey:ID;AssociationForeignKey:DrugId" json:"drug"`
	Manufacturers    Manufacturer `gorm:"ForeignKey:ID;AssociationForeignKey:Manufacturer" json:"Manufacturer"`
	Dealers          Dealers      `gorm:"ForeignKey:ID;AssociationForeignKey:Dealer" json:"Dealer"`

	BatchNumber               string `gorm:"column:batch_number" json:"batch_number" form:"batch_number"`
	MaxUnit                   string `gorm:"column:max_unit" json:"max_unit" form:"max_unit"`
	MinUnit                   string `gorm:"column:min_unit" json:"min_unit" form:"min_unit"`
	StockMaxNumber            int64  `gorm:"column:stock_max_number" json:"stock_max_number" form:"stock_max_number"`
	StockMinNumber            int64  `gorm:"column:stock_min_number" json:"stock_min_number" form:"stock_min_number"`
	WarehousingInfoId         int64  `gorm:"column:warehousing_info_id" json:"warehousing_info_id" form:"warehousing_info_id"`
	SupplyWarehouseId         int64  `gorm:"column:supply_warehouse_id" json:"supply_warehouse_id" form:"supply_warehouse_id"`
	SupplyWarehouseDetailInfo int64  `gorm:"column:supply_warehouse_detail_info" json:"supply_warehouse_detail_info" form:"supply_warehouse_detail_info"`
	StorehouseId              int64  `gorm:"column:storehouse_id" json:"storehouse_id" form:"storehouse_id"`
	SecondWarehouseInfoId     int64  `gorm:"column:second_warehouse_info_id" json:"second_warehouse_info_id" form:"second_warehouse_info_id"`
	IsCheck                   int64  `gorm:"column:is_check" json:"is_check" form:"is_check"`

	IsPc     int64  `gorm:"column:is_pc" json:"is_pc" form:"is_pc"`
	IsBg     int64  `gorm:"column:is_bg" json:"is_bg" form:"is_bg"`
	Bchno    string `gorm:"column:bchno" json:"bchno" form:"bchno"`
	PcDate   int64  `gorm:"column:pc_date" json:"pc_date" form:"pc_date"`
	BgBchno  string `gorm:"column:bg_bchno" json:"bg_bchno" form:"bg_bchno"`
	DrugCode string `gorm:"column:drug_code" json:"drug_code" form:"drug_code"`
}

func (NewDrugWarehouseInfo) TableName() string {
	return "xt_drug_warehouse_info"
}

type NewDrugWarehouseOut struct {
	ID                      int64         `gorm:"column:id" json:"id" form:"id"`
	WarehouseOutOrderNumber string        `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number" form:"warehouse_out_order_number"`
	OperationTime           int64         `gorm:"column:operation_time" json:"operation_time" form:"operation_time"`
	Creater                 int64         `gorm:"column:creater" json:"creater" form:"creater"`
	OrgId                   int64         `gorm:"column:org_id" json:"org_id" form:"org_id"`
	Modifier                int64         `gorm:"column:modifier" json:"modifier" form:"modifier"`
	Remark                  string        `gorm:"column:remark" json:"remark" form:"remark"`
	Ctime                   int64         `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                   int64         `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status                  int64         `gorm:"column:status" json:"status" form:"status"`
	WarehouseOutTime        int64         `gorm:"column:warehouse_out_time" json:"warehouse_out_time" form:"warehouse_out_time"`
	Dealer                  int64         `gorm:"column:dealer" json:"dealer" form:"dealer"`
	Manufacturer            int64         `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	Type                    int64         `gorm:"column:type" json:"type" form:"type"`
	IsSys                   int64         `gorm:"column:is_sys" json:"is_sys" form:"is_sys"`
	Manufacturers           *Manufacturer `gorm:"ForeignKey:Manufacturer;AssociationForeignKey:ID" json:"manufacturers"`
	Dealers                 *Dealers      `gorm:"ForeignKey:Dealer;AssociationForeignKey:ID" json:"dealers"`
}

func (NewDrugWarehouseOut) TableName() string {
	return "xt_drug_warehouse_out"
}

type NewDrugWarehouseOutInfo struct {
	ID                      int64                `gorm:"column:id" json:"id" form:"id"`
	WarehouseOutId          int64                `gorm:"column:warehouse_out_id" json:"warehouse_out_id" form:"warehouse_out_id"`
	DrugId                  int64                `gorm:"column:drug_id" json:"drug_id" form:"drug_id"`
	WarehousingOutTarget    int64                `gorm:"column:warehousing_out_target" json:"warehousing_out_target" form:"warehousing_out_target"`
	Count                   int64                `gorm:"column:count" json:"count" form:"count"`
	Price                   float64              `gorm:"column:price" json:"price" form:"price"`
	TotalPrice              float64              `gorm:"column:total_price" json:"total_price" form:"total_price"`
	ProductDate             int64                `gorm:"column:product_date" json:"product_date" form:"product_date"`
	ExpiryDate              int64                `gorm:"column:expiry_date" json:"expiry_date" form:"expiry_date"`
	Mtime                   int64                `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Ctime                   int64                `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Status                  int64                `gorm:"column:status" json:"status" form:"status"`
	OrgId                   int64                `gorm:"column:org_id" json:"org_id" form:"org_id"`
	Remark                  string               `gorm:"column:remark" json:"remark" form:"remark"`
	IsCancel                int64                `gorm:"column:is_cancel" json:"is_cancel" form:"is_cancel"`
	WarehouseOutOrderNumber string               `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number" form:"warehouse_out_order_number"`
	Type                    int64                `gorm:"column:type" json:"type" form:"type"`
	Dealer                  int64                `gorm:"column:dealer" json:"dealer" form:"dealer"`
	Manufacturer            int64                `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	IsSys                   int64                `gorm:"column:is_sys" json:"is_sys" form:"is_sys"`
	SysRecordTime           int64                `gorm:"column:sys_record_time" json:"sys_record_time" form:"sys_record_time"`
	RetailPrice             float64              `gorm:"column:retail_price" json:"retail_price" form:"retail_price"`
	RetailTotalPrice        float64              `gorm:"column:retail_total_price" json:"retail_total_price" form:"retail_total_price"`
	BaseDrugLib             BaseDrugLib          `gorm:"ForeignKey:ID;AssociationForeignKey:DrugId" json:"drug"`
	Manufacturers           Manufacturer         `gorm:"ForeignKey:ID;AssociationForeignKey:Manufacturer" json:"Manufacturer"`
	Dealers                 Dealers              `gorm:"ForeignKey:ID;AssociationForeignKey:Dealer" json:"Dealer"`
	BatchNumber             string               `gorm:"column:batch_number" json:"batch_number" form:"batch_number"`
	WarehouseInfoId         int64                `gorm:"column:warehouse_info_id" json:"warehouse_info_id" form:"warehouse_info_id"`
	NewDrugWarehouseInfo    NewDrugWarehouseInfo `gorm:"ForeignKey:ID;AssociationForeignKey:WarehouseInfoId" json:"in_info"`
}

func (NewDrugWarehouseOutInfo) TableName() string {
	return "xt_drug_warehouse_out_info"
}

type NewDrugCancelStock struct {
	ID            int64         `gorm:"column:id" json:"id" form:"id"`
	OrderNumber   string        `gorm:"column:order_number" json:"order_number" form:"order_number"`
	OperaTime     int64         `gorm:"column:opera_time" json:"opera_time" form:"opera_time"`
	Total         int64         `gorm:"column:total" json:"total" form:"total"`
	Creater       int64         `gorm:"column:creater" json:"creater" form:"creater"`
	Ctime         int64         `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime         int64         `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status        int64         `gorm:"column:status" json:"status" form:"status"`
	OrgId         int64         `gorm:"column:org_id" json:"org_id" form:"org_id"`
	ReturnTime    int64         `gorm:"column:return_time" json:"return_time" form:"return_time"`
	Dealer        int64         `gorm:"column:dealer" json:"dealer" form:"dealer"`
	Manufacturer  int64         `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	Type          int64         `gorm:"column:type" json:"type" form:"type"`
	Manufacturers *Manufacturer `gorm:"ForeignKey:Manufacturer;AssociationForeignKey:ID" json:"manufacturers"`
	Dealers       *Dealers      `gorm:"ForeignKey:Dealer;AssociationForeignKey:ID" json:"dealers"`
}

func (NewDrugCancelStock) TableName() string {
	return "xt_drug_cancel_stock"
}

type NewDrugCancelStockInfo struct {
	ID               int64        `gorm:"column:id" json:"id" form:"id"`
	DrugId           int64        `gorm:"column:drug_id" json:"drug_id" form:"drug_id"`
	CancelStockId    int64        `gorm:"column:cancel_stock_id" json:"cancel_stock_id" form:"cancel_stock_id"`
	Count            int64        `gorm:"column:count" json:"count" form:"count"`
	Price            float64      `gorm:"column:price" json:"price" form:"price"`
	Total            float64      `gorm:"column:total" json:"total" form:"total"`
	ProductDate      int64        `gorm:"column:product_date" json:"product_date" form:"product_date"`
	ExpiryDate       int64        `gorm:"column:expiry_date" json:"expiry_date" form:"expiry_date"`
	Ctime            int64        `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime            int64        `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status           int64        `gorm:"column:status" json:"status" form:"status"`
	OrgId            int64        `gorm:"column:org_id" json:"org_id" form:"org_id"`
	OrderNumber      string       `gorm:"column:order_number" json:"order_number" form:"order_number"`
	Type             int64        `gorm:"column:type" json:"type" form:"type"`
	Dealer           int64        `gorm:"column:dealer" json:"dealer" form:"dealer"`
	Manufacturer     int64        `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	RetailPrice      float64      `gorm:"column:retail_price" json:"retail_price" form:"retail_price"`
	RetailTotalPrice float64      `gorm:"column:retail_total_price" json:"retail_total_price" form:"retail_total_price"`
	Number           string       `gorm:"column:number" json:"number" form:"number"`
	BaseDrugLib      BaseDrugLib  `gorm:"ForeignKey:ID;AssociationForeignKey:DrugId" json:"drug"`
	Manufacturers    Manufacturer `gorm:"ForeignKey:ID;AssociationForeignKey:Manufacturer" json:"Manufacturer"`
	Dealers          Dealers      `gorm:"ForeignKey:ID;AssociationForeignKey:Dealer" json:"Dealer"`
	BatchNumber      string       `gorm:"column:batch_number" json:"batch_number" form:"batch_number"`
}

func (NewDrugCancelStockInfo) TableName() string {
	return "xt_drug_cancel_stock_info"
}

type DrugFlow struct {
	ID                        int64                `gorm:"column:id" json:"id" form:"id"`
	WarehousingId             int64                `gorm:"column:warehousing_id" json:"warehousing_id" form:"warehousing_id"`
	DrugId                    int64                `gorm:"column:drug_id" json:"drug_id" form:"drug_id"`
	Number                    string               `gorm:"column:number" json:"number" form:"number"`
	BatchNumber               string               `gorm:"column:batch_number" json:"batch_number" form:"batch_number"`
	Count                     int64                `gorm:"column:count" json:"count" form:"count"`
	UserOrgId                 int64                `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId                 int64                `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	SystemTime                int64                `gorm:"column:system_time" json:"system_time" form:"system_time"`
	ConsumableType            int64                `gorm:"column:consumable_type" json:"consumable_type" form:"consumable_type"`
	IsSys                     int64                `gorm:"column:is_sys" json:"is_sys" form:"is_sys"`
	WarehousingOrder          string               `gorm:"column:warehousing_order" json:"warehousing_order" form:"warehousing_order"`
	WarehouseOutId            int64                `gorm:"column:warehouse_out_id" json:"warehouse_out_id" form:"warehouse_out_id"`
	WarehouseOutOrderNumber   string               `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number" form:"warehouse_out_order_number"`
	IsEdit                    int64                `gorm:"column:is_edit" json:"is_edit" form:"is_edit"`
	CancelStockId             int64                `gorm:"column:cancel_stock_id" json:"cancel_stock_id" form:"cancel_stock_id"`
	CancelOrderNumber         string               `gorm:"column:cancel_order_number" json:"cancel_order_number" form:"cancel_order_number"`
	Manufacturer              int64                `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	Dealer                    int64                `gorm:"column:dealer" json:"dealer" form:"dealer"`
	Creator                   int64                `gorm:"column:creator" json:"creator" form:"creator"`
	UpdateCreator             int64                `gorm:"column:update_creator" json:"update_creator" form:"update_creator"`
	Status                    int64                `gorm:"column:status" json:"status" form:"status"`
	Ctime                     int64                `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                     int64                `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Price                     float64              `gorm:"column:price" json:"price" form:"price"`
	WarehousingDetailId       int64                `gorm:"column:warehousing_detail_id" json:"warehousing_detail_id" form:"warehousing_detail_id"`
	WarehouseOutDetailId      int64                `gorm:"column:warehouse_out_detail_id" json:"warehouse_out_detail_id" form:"warehouse_out_detail_id"`
	CancelOutDetailId         int64                `gorm:"column:cancel_out_detail_id" json:"cancel_out_detail_id" form:"cancel_out_detail_id"`
	ExpireDate                int64                `gorm:"column:expire_date" json:"expire_date" form:"expire_date"`
	ProductDate               int64                `gorm:"column:product_date" json:"product_date" form:"product_date"`
	MaxUnit                   string               `gorm:"column:max_unit" json:"max_unit" form:"max_unit"`
	MinUnit                   string               `gorm:"column:min_unit" json:"min_unit" form:"min_unit"`
	StockMaxNumber            int64                `gorm:"column:stock_max_number" json:"stock_max_number" form:"stock_max_number"`
	StockMinNumber            int64                `gorm:"column:stock_min_number" json:"stock_min_number" form:"stock_min_number"`
	LastStockMaxNumber        int64                `gorm:"column:last_stock_max_number" json:"last_stock_max_number" form:"last_stock_max_number"`
	LastStockMinNumber        int64                `gorm:"column:last_stock_min_number" json:"last_stock_min_number" form:"last_stock_min_number"`
	AdviceId                  int64                `gorm:"column:advice_id" json:"advice_id" form:"advice_id"`
	HisDoctorAdviceInfo       HisDoctorAdviceInfo  `gorm:"ForeignKey:PatientId,RecordDate,DrugId;AssociationForeignKey:PatientId,SystemTime,DrugId" json:"advice"`
	SupplyWarehouseId         int64                `gorm:"column:supply_warehouse_id" json:"supply_warehouse_id" form:"supply_warehouse_id"`
	SupplyCancelOutId         int64                `gorm:"column:supply_cancel_out_id" json:"supply_cancel_out_id" form:"supply_cancel_out_id"`
	SupplyWarehouseDetailInfo int64                `gorm:"column:supply_warehouse_detail_info" json:"supply_warehouse_detail_info" form:"supply_warehouse_detail_info"`
	StorehouseId              int64                `gorm:"column:storehouse_id" json:"storehouse_id" form:"storehouse_id"`
	SecondWarehouseInfoId     int64                `gorm:"column:second_warehouse_info_id" json:"second_warehouse_info_id" form:"second_warehouse_info_id"`
	AdminUserId               int64                `gorm:"column:admin_user_id" json:"admin_user_id" form:"admin_user_id"`
	LastPrice                 float64              `gorm:"column:last_price" json:"last_price" form:"last_price"`
	StockCount                string               `gorm:"column:stock_count" json:"stock_count" form:"stock_count"`
	PharmacyId                int64                `gorm:"column:pharmacy_id" json:"pharmacy_id" form:"pharmacy_id"`
	IsRead                    int64                `gorm:"column:is_read" json:"is_read" form:"is_read"`
	IsCheck                   int64                `gorm:"column:is_check" json:"is_check" form:"is_check"`
	OverCount                 int64                `gorm:"column:over_count" json:"over_count" form:"over_count"`
	RetailPrice               float64              `gorm:"column:retail_price" json:"retail_price" form:"retail_price"`
	OrderId                   int64                `gorm:"column:order_id" json:"order_id" form:"order_id"`
	IsSale                    int64                `gorm:"column:is_sale" json:"is_sale" form:"is_sale"`
	IsChange                  int64                `gorm:"column:is_change" json:"is_change" form:"is_change"`
	NewDrugWarehouseInfo      NewDrugWarehouseInfo `gorm:"ForeignKey:ID;AssociationForeignKey:WarehousingDetailId" json:"dw"`
	Bchno                     string               `gorm:"column:bchno" json:"bchno" form:"bchno"`
	SaleDate                  string               `gorm:"column:sale_date" json:"sale_date" form:"sale_date"`
	BgBchno                   string               `gorm:"column:bg_bchno" json:"bg_bchno" form:"bg_bchno"`
	DrugCode                  string               `gorm:"column:drug_code" json:"drug_code" form:"drug_code"`
}

func (DrugFlow) TableName() string {
	return "xt_drug_flow"
}
